<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 15/01/20
 * Time: 8.59
 */

namespace FiloBlu\Rma\Helper;
use Magento\Eav\Model\AttributeRepository;
use Psr\Log\LoggerInterface;
use Magento\Eav\Model\ResourceModel\Entity\Attribute\Option\Collection;

class ChangeSizeAttributeHelper
{

    const REASON_CHANGE_SIZE_LABEL='Change Size';
    const REASON_CHANGE_SIZE_ENTITY_CODE ='rma_item';
    const RMA_RESOLUTION_ATTRIBUTE_CODE = 'resolution';
    const ORDER_STATUS_CHANGESIZE_CODE = 'change_size';
    const ORDER_STATUS_CHANGESIZE_LABEL = 'Change Size Order';
    const CHANGE_SIZE_RMA_ATTRIBUTE_CODE = 'change_size';
    const RESOLUTION_CHANGE_SIZE_OPTION_CODE = 'change_size';

    /**
     * @var AttributeRepository
     */
    protected $attributeRepository;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var Collection
     */
    protected $attributeOptionCollection;


    /**
     * ChangeSizeAttributeHelper constructor.
     * @param AttributeRepository $attributeRepository
     * @param LoggerInterface $logger
     * @param Collection $attributeOptionCollection
     */
    public function __construct(AttributeRepository $attributeRepository,
                                LoggerInterface $logger,
                                Collection $attributeOptionCollection)
    {
        $this->attributeRepository = $attributeRepository;
        $this->logger = $logger;
        $this->attributeOptionCollection = $attributeOptionCollection;
    }

    /**
     * @return int|string
     */
    public function getChangeSizeAttributeId()
    {
        try
        {
            $resolution = $this->attributeRepository->get(self::REASON_CHANGE_SIZE_ENTITY_CODE,self::RMA_RESOLUTION_ATTRIBUTE_CODE);
            $resolutionOptions = $resolution->getOptions();
            $id =0;
            foreach ($resolutionOptions as $option)
            {
                if($option->getLabel() == self::REASON_CHANGE_SIZE_LABEL)
                {
                    $id =$option->getValue();
                }
            }
            return $id;
        }
        catch (\Exception $e)
        {
            $this->logger->critical($e->getMessage());
            return $id;
        }


    }

    /**
     * @param int $storeId
     * @return string
     */
    public function getChangeSizeLabelByStoreId($storeId = 0){
        try{
            $chageSizeOption = $this->attributeOptionCollection->addFieldToFilter('main_table.option_id',['eq'=>$this->getChangeSizeAttributeId()])->setStoreFilter($storeId)->getFirstItem();
            $label=$chageSizeOption->getValue() ?? '';

            return $label;
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
            return $label;
        }

    }

    /**
     * @return array
     */
    public function getAllChangeSizeLabel(){
        try{
            $chageSizeOptions = $this->attributeOptionCollection->addFieldToFilter('main_table.option_id',['eq'=>$this->getChangeSizeAttributeId()])->distinct(true)->getItems();
            $labels = [];
            foreach ($chageSizeOptions as $option){
                $labels [] = $option->getValue();
            }
            return $labels;
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
            return [];
        }

    }

}